<?php
/*
Plugin Name: HitCount
Description: Counts page hits and visitors
Version: 0.9.1
Author: Martin Vlcek
Author URI: http://mvlcek.bplaced.net

Public functions:
	return_hitcount_hits($slug)
		returns the hits for the page identified by $slug, normally return_page_slug()
	return_hitcount_visits()
		returns the number of visits to the site
*/

# get correct id for plugin
$thisfile = basename(__FILE__, ".php");

define('HITCOUNT_DIR', 'hitcount/'); 

# register plugin
register_plugin(
	$thisfile, 
	'HitCount', 	
	'0.9.1', 		
	'Martin Vlcek',
	'http://mvlcek.bplaced.net', 
	'Counts page hits and visitors',
	'support',
	'hitcount_overview'  
);

# activate filter
add_action('index-pretemplate', 'hitcount_init');
add_action('support-sidebar', 'createSideMenu', array($thisfile, 'Hits & Visitors'));

function return_hitcount_hits($slug) {
  $hits = @file(GSDATAOTHERPATH . HITCOUNT_DIR . 'hits_' . $slug . '.txt');
	return $hits ? $hits[0] : 0;
}

function return_hitcount_visits() {
	$visits = @file(GSDATAOTHERPATH . HITCOUNT_DIR . 'visits.txt');
	return $visits ? $visits[0] : 0;
}

function hitcount_init() {
  global $url;
  $hcdir = GSDATAOTHERPATH . HITCOUNT_DIR;
  if (!file_exists($hcdir)) {
    mkdir(substr($hcdir,0,strlen($hcdir)-1), 0777);
    $fp = fopen($hcdir . '.htaccess', 'w');
    fputs($fp, 'Deny from all');
    fclose($fp);
  }
  @session_start();
  $lp = fopen(GSDATAOTHERPATH . HITCOUNT_DIR . 'lock.txt', 'w');
  if (flock($lp, LOCK_EX)) {
    # visitors
    if (!isset($_SESSION['hitcount_visits'])) {
      $_SESSION['hitcount_visits'] = hitcount_count($hcdir . 'visits.txt');
    }
    # hits
    hitcount_count($hcdir . 'hits_' . $url . '.txt');
    # log
    $fp = fopen(GSDATAOTHERPATH . HITCOUNT_DIR . 'log.txt', 'a');
    $referer = @$_SERVER["HTTP_REFERER"];
    $useragent = @$_SERVER["HTTP_USER_AGENT"];
    fputs($fp, time() . " " . $_SESSION['hitcount_visits'] . " " . $url . " " . $referer . " " . $useragent . "\n");
    fclose($fp);
    flock($lp, LOCK_UN);
  }
  fclose($lp);
}

function hitcount_count($hcfile) {
  if (file_exists($hcfile)) {
    $hits = file($hcfile);
    $hits = $hits[0] + 1;
  } else {
    $hits = 1;
  }
  $fp = fopen($hcfile, 'w');
  fputs($fp, $hits);
  fclose($fp);
  return $hits;
}

function hitcount_reset() {
  $dir_handle = @opendir(GSDATAOTHERPATH . HITCOUNT_DIR) or die("Unable to open hitcount directory");
  while ($filename = readdir($dir_handle)) {
    if (!is_dir(GSDATAOTHERPATH . HITCOUNT_DIR . $filename) && $filename != '.htaccess') {
      unlink(GSDATAOTHERPATH . HITCOUNT_DIR . $filename);
    }
  }
}

function hitcount_overview() {
  if (isset($_REQUEST['hitcount_reset'])) hitcount_reset();
  if (isset($_REQUEST['hitcount_time'])) {
    hitcount_show_time();
  } else if (isset($_REQUEST['hitcount_referers'])) {
    hitcount_show_referers();
  } else if (isset($_REQUEST['hitcount_useragents'])) {
    hitcount_show_useragents();
  } else if (isset($_REQUEST['hitcount_duration'])) {
    hitcount_show_duration();
  } else if (isset($_REQUEST['hitcount_os'])) {
    hitcount_show_os();
  } else if (isset($_REQUEST['hitcount_browsers'])) {
    hitcount_show_browsers();
  } else if (isset($_REQUEST['hitcount_languages'])) {
    hitcount_show_languages();
  } else {
    hitcount_show_hitcounts();
  }
}

function hitcount_show_links($current) {
  $link = "load.php?id=hitcount";
  echo "<div class=\"edit-nav\">";
  if ($current != 'hitcounts') echo "<a href=\"{$link}&hitcount_hitcounts=1\">Hits</a> ";
  if (false && $current != 'time') echo "<a href=\"{$link}&hitcount_time=1\">Time</a> ";
  if ($current != 'referers') echo "<a href=\"{$link}&hitcount_referers=1\">Referers</a> ";
  if ($current != 'useragents') echo "<a href=\"{$link}&hitcount_useragents=1\">User agents</a> ";
  if ($current != 'duration') echo "<a href=\"{$link}&hitcount_duration=1\">Duration</a> ";
  if ($current != 'os') echo "<a href=\"{$link}&hitcount_os=1\">OS</a> ";
  if ($current != 'browsers') echo "<a href=\"{$link}&hitcount_browsers=1\">Browsers</a> ";
  if ($current != 'languages') echo "<a href=\"{$link}&hitcount_languages=1\">Languages</a> ";
  echo "<div class=\"clear\"></div></div>";
}

function hitcount_show_amount($num, $max) {
	if ($max) {
		$perc = (int) (100 * $num / $max);
		echo "<div style=\"position:relative\">&nbsp;<div style=\"position:absolute;z-index:5;top:0;width:100%\">$num</div><div style=\"position:absolute;left:0;top:0.7em;width:$perc%;height:40%;background-color:#eec6b9;z-index:1\"></div></div>";
	} else {
		echo $num;
	}
}

function hitcount_show_time() {
?>
  <label>Hits &amp; Visitors over Time</label><?php hitcount_show_links('time'); ?>
<?php
}

function hitcount_show_referers() {
  include(GSPLUGINPATH.'hitcount/referers.php');
}

function hitcount_show_useragents() {
  include(GSPLUGINPATH.'hitcount/useragents.php');
}

function hitcount_show_os() {
  include(GSPLUGINPATH.'hitcount/os.php');
}

function hitcount_show_browsers() {
  include(GSPLUGINPATH.'hitcount/browsers.php');
}

function hitcount_show_languages() {
  include(GSPLUGINPATH.'hitcount/languages.php');
}

function hitcount_show_duration() {
  include(GSPLUGINPATH.'hitcount/duration.php');
}

function hitcount_show_hitcounts() {
  include(GSPLUGINPATH.'hitcount/hitcounts.php');
}


